@@ -622,13 +622,15 @@ class FindOntologyData(BaseObject):
         return self._merge(results, QueryResultType.DICT_OF_STR2DICT)
 
     @lru_cache
-    def span_keys(self) -> list:
+    def span_keys(self) -> Optional[list]:
         """ Return Span Keys sorted by Length
 
         Returns:
             list: list of span keys sorted by length
         """
-        return sorted(self.spans().keys(), key=len)
+        spans = self.spans()
+        if spans and len(spans):
+            return sorted(self.spans().keys(), key=len)
 
     def synonyms(self) -> dict:
         """ Return Synonyms keyed by Entity Name
