@@ -47,6 +47,11 @@ class GenerateViewSpans(BaseObject):
             craigtrim@gmail.com
             *   deal with CSV lists in rdfs:seeAlso relationship
                 https://github.com/craigtrim/owl-finder/issues/2#issuecomment-1326808994
+        Updated:
+            28-Nov-2022
+            craigtrim@gmail.com
+            *   use hash to ensure uniqueness in spans
+                https://github.com/craigtrim/owl-finder/issues/4#issuecomment-1329990189
         """
         BaseObject.__init__(self, __name__)
 
@@ -136,6 +141,8 @@ class GenerateViewSpans(BaseObject):
                 d_results: dict) -> dict:
 
         d = defaultdict(list)
+
+        hashes = set()
         d_results = self._normalize(d_results)
 
         def update(canon: str,
@@ -144,8 +151,18 @@ class GenerateViewSpans(BaseObject):
             trigger = tokens[0]
 
             d_result = self._to_dict(canon, tokens)
+
             if d_result:
-                d[trigger].append(d_result)
+
+                # 20221128; Ensure Uniqueness
+                # https://github.com/craigtrim/owl-finder/issues/4#issuecomment-1329990189
+                hash_d_result = hash(''.join([
+                    str(x) for x in d_result.values()
+                ]))
+
+                if hash_d_result not in hashes:
+                    d[trigger].append(d_result)
+                    hashes.add(hash_d_result)
 
         for k in d_results:
             update(canon=k, term=k)
